@@ -28,7 +28,3 @@ from mlphys.deepqis.optimization import bme, linear_inversion, mle
 from mlphys.fso.lgoam.source import OAM_Intensity_Phase
 from mlphys.fso.turbulence import gdo_corrected_phase_mask, phase_mask, propagate
 
-import configparser
-parser = configparser.ConfigParser()
-parser.read('config.ini')
-__version__ = parser['VERSION']['version']
