@@ -1,6 +1,6 @@
 """
 author: Sanjaya Lohani
-email: slohani@mlphys_nightly.com
+email: slohani@mlphys.com
 Licence: Apache-2.0
 """
 '''
@@ -9,7 +9,7 @@ It only works for the two qubit case
 import numpy as np
 
 __author__ = 'Sanjaya Lohani'
-__email__ = 'slohani@mlphys_nightly.com'
+__email__ = 'slohani@mlphys.com'
 __licence__ = 'Apache 2.0'
 __website__ = "sanjayalohani.com"
 
