@@ -1,6 +1,6 @@
 """
 author: Sanjaya Lohani
-email: slohani@mlphys_nightly.com
+email: slohani@mlphys.com
 Licence: Apache-2.0
 """
 import tensorflow as tf
