@@ -1,13 +1,13 @@
 '''
 author: Sanjaya Lohani
-email: slohani@mlphys_nightly.com
+email: slohani@mlphys.com
 '''
 
 import tensorflow as tf
 import tensorflow_probability as tfp
 
 __author__ = 'Sanjaya Lohani'
-__email__ = 'slohani@mlphys_nightly.com'
+__email__ = 'slohani@mlphys.com'
 __licence__ = 'Apache 2.0'
 __website__ = "sanjayalohani.com"
 
